==> resin-4.0.32-src.tar.gz: resin-4.0.32/modules/resin/src/com/caucho/bam/proxy/AbstractReplyCallback.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.bam.proxy;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.caucho.bam.BamError;

/**
 * callback for a proxy rpc.
 */
public class AbstractReplyCallback<T> implements ReplyCallback<T> {
  private static final Logger log
    = Logger.getLogger(AbstractReplyCallback.class.getName());
  
  @Override
  public void onReply(T result)
  {
    log.log(Level.FINER, this + " onResult() -> " + result);
  }
  
  @Override
  public void onError(BamError error)
  {
    log.log(Level.FINER, this + " onError() -> " + error);
  }
  
  @Override
  public String toString()
  {
    return getClass().getSimpleName() + "[]";
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/bam/proxy/AbstractReplyCallback.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *
 *   Free Software Foundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.bam.proxy;

import java.util.logging.Level;
import java.util.logging.Logger;

import com.caucho.bam.BamError;

/**
 * callback for a proxy rpc.
 */
public class AbstractReplyCallback<T> implements ReplyCallback<T> {
  private static final Logger log
    = Logger.getLogger(AbstractReplyCallback.class.getName());
  
  @Override
  public void onReply(T result)
  {
    if (log.isLoggable(Level.FINEST)) { 
      log.log(Level.FINEST, this + " onResult() -> " + result);
    }
  }
  
  @Override
  public void onError(BamError error)
  {
    if (log.isLoggable(Level.FINEST)) { 
      log.log(Level.FINEST, this + " onError() -> " + error);
    }
  }
  
  @Override
  public String toString()
  {
    return getClass().getSimpleName() + "[]";
  }
}
